@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 use base 'Pod::Parser';
 
@@ -205,7 +205,7 @@ __END__
 
 =pod
 
-=encoding latin1
+=encoding UTF-8
 
 =head1 NAME
 
@@ -213,7 +213,7 @@ Pod::Spell - a formatter for spellchecking Pod
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -406,7 +406,7 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Olivier Mengu <dolmen@cpan.org>
+Olivier Mengué <dolmen@cpan.org>
 
 =back
 
@@ -426,7 +426,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing.
+This software is Copyright (c) 2014 by Caleb Cushing.
 
 This is free software, licensed under:
 
